IHAVETO: A simple todo list for Developers
=======================

This is a simple TODO list for developers.
I made this app to my self because I'm a crazy developer and I prefer to do everything in a terminal window.